summaryrefslogtreecommitdiff
path: root/src/theory/quantifiers/single_inv_partition.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/quantifiers/single_inv_partition.cpp')
-rw-r--r--src/theory/quantifiers/single_inv_partition.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/theory/quantifiers/single_inv_partition.cpp b/src/theory/quantifiers/single_inv_partition.cpp
index 72a1a2856..1dbc24280 100644
--- a/src/theory/quantifiers/single_inv_partition.cpp
+++ b/src/theory/quantifiers/single_inv_partition.cpp
@@ -20,11 +20,11 @@
#include "theory/quantifiers/term_util.h"
#include "theory/rewriter.h"
-using namespace CVC4;
-using namespace CVC4::kind;
+using namespace CVC5;
+using namespace CVC5::kind;
using namespace std;
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
namespace quantifiers {
@@ -613,6 +613,6 @@ void SingleInvocationPartition::debugPrint(const char* c)
Trace(c) << std::endl;
}
-} /* namespace CVC4::theory::quantifiers */
-} /* namespace CVC4::theory */
-} /* namespace CVC4 */
+} // namespace quantifiers
+} // namespace theory
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback